@@ -454,7 +454,7 @@ class Miniterm(object):
         logdir = os.path.join(str(Path.home()), 'xMesh-Assistant')
         if not os.path.exists(logdir):
             os.mkdir(logdir)
-        self.logpath = os.path.join(logdir, f'{time.strftime("%Y-%m-%d_%H:%M:%S", time.localtime())}.raw')
+        self.logpath = os.path.join(logdir, f'{time.strftime("%Y-%m-%d_%H-%M-%S", time.localtime())}.raw')
         self.logfile = open(self.logpath, 'w')
         self._start_reader()
         # enter console->serial loop
